summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorPablo Saratxaga <pablo@mandriva.com>2005-04-23 16:20:27 +0000
committerPablo Saratxaga <pablo@mandriva.com>2005-04-23 16:20:27 +0000
commitca012347134ab4eec6f196b5f86c9fc1f25cb5b7 (patch)
tree5fc5930cd84d8b9f74f82a13bd26b2fe4de10ac3
parent0d46fdc4ff12e12d75709007659a334b90d34ead (diff)
downloaddrakx-backup-do-not-use-ca012347134ab4eec6f196b5f86c9fc1f25cb5b7.tar
drakx-backup-do-not-use-ca012347134ab4eec6f196b5f86c9fc1f25cb5b7.tar.gz
drakx-backup-do-not-use-ca012347134ab4eec6f196b5f86c9fc1f25cb5b7.tar.bz2
drakx-backup-do-not-use-ca012347134ab4eec6f196b5f86c9fc1f25cb5b7.tar.xz
drakx-backup-do-not-use-ca012347134ab4eec6f196b5f86c9fc1f25cb5b7.zip
s/Mandrivalinux/Mandriva Linux/
-rw-r--r--perl-install/any.pm2
-rw-r--r--perl-install/help.pm54
-rw-r--r--perl-install/install_interactive.pm2
-rw-r--r--perl-install/network/adsl.pm2
-rw-r--r--perl-install/network/drakfirewall.pm2
-rw-r--r--perl-install/printer/printerdrake.pm4
-rwxr-xr-xperl-install/standalone/drakbug10
-rwxr-xr-xperl-install/standalone/drakconnect6
-rw-r--r--perl-install/standalone/drakedm4
-rw-r--r--perl-install/standalone/drakhelp2
-rwxr-xr-xperl-install/standalone/logdrake4
-rw-r--r--perl-install/standalone/net_applet2
-rwxr-xr-xperl-install/standalone/net_monitor4
-rwxr-xr-xperl-install/standalone/scannerdrake8
14 files changed, 53 insertions, 53 deletions
diff --git a/perl-install/any.pm b/perl-install/any.pm
index 2009373aa..697022a47 100644
--- a/perl-install/any.pm
+++ b/perl-install/any.pm
@@ -730,7 +730,7 @@ sub selectLanguage {
my $last_utf8 = $in->{locale}{utf8};
add2hash($common, { cancel => '',
- advanced_messages => formatAlaTeX(N("Mandrivalinux can support multiple languages. Select
+ advanced_messages => formatAlaTeX(N("Mandriva Linux can support multiple languages. Select
the languages you would like to install. They will be available
when your installation is complete and you restart your system.")),
advanced_state => 1,
diff --git a/perl-install/install_interactive.pm b/perl-install/install_interactive.pm
index 6fd56a736..8cc936d3d 100644
--- a/perl-install/install_interactive.pm
+++ b/perl-install/install_interactive.pm
@@ -160,7 +160,7 @@ the following error occurred: %s", formatError($@));
#- this save at least a cylinder (less than 8Mb).
$min_win += partition_table::raw::cylinder_size($hd);
- $part->{size} > $min_linux + $min_swap + $min_freewin + $min_win or die N("Your Windows partition is too fragmented. Please reboot your computer under Windows, run the ``defrag'' utility, then restart the Mandrivalinux installation.");
+ $part->{size} > $min_linux + $min_swap + $min_freewin + $min_win or die N("Your Windows partition is too fragmented. Please reboot your computer under Windows, run the ``defrag'' utility, then restart the Mandriva Linux installation.");
$o->ask_okcancel('', formatAlaTeX(
#-PO: keep the double empty lines between sections, this is formatted a la LaTeX
N("WARNING!
diff --git a/perl-install/network/adsl.pm b/perl-install/network/adsl.pm
index fc7d7d95e..e521443b9 100644
--- a/perl-install/network/adsl.pm
+++ b/perl-install/network/adsl.pm
@@ -379,7 +379,7 @@ METRIC=$metric
$modules_conf->set_alias($_->[0], $_->[1]) foreach @{$modems{$adsl_device}{aliases}};
$::isStandalone and $modules_conf->write;
}
- #- remove the "speedtch off" alias that was written by Mandrivalinux 10.0
+ #- remove the "speedtch off" alias that was written by Mandrakelinux 10.0
$adsl_device eq 'speedtouch' and $modules_conf->remove_alias('speedtch');
if ($adsl_type eq "capi") {
diff --git a/perl-install/network/drakfirewall.pm b/perl-install/network/drakfirewall.pm
index 6f5ec9183..bfe7bd7e7 100644
--- a/perl-install/network/drakfirewall.pm
+++ b/perl-install/network/drakfirewall.pm
@@ -157,7 +157,7 @@ sub get_conf {
} else {
$in->ask_okcancel('', N("drakfirewall configurator
-This configures a personal firewall for this Mandrivalinux machine.
+This configures a personal firewall for this Mandriva Linux machine.
For a powerful and dedicated firewall solution, please look to the
specialized MandrakeSecurity Firewall distribution."), 1) or return;
diff --git a/perl-install/printer/printerdrake.pm b/perl-install/printer/printerdrake.pm
index 28edf501e..7418119cd 100644
--- a/perl-install/printer/printerdrake.pm
+++ b/perl-install/printer/printerdrake.pm
@@ -19,7 +19,7 @@ my $recstr = $printer::main::recstr;
my $precstr = $printer::main::precstr;
my $sprecstr = $printer::main::sprecstr;
-my $shortdistroname = "Mandrivalinux";
+my $shortdistroname = "Mandriva Linux";
my $hp1000fwtext = N("The HP LaserJet 1000 needs its firmware to be uploaded after being turned on. Download the Windows driver package from the HP web site (the firmware on the printer's CD does not work) and extract the firmware file from it by decompressing the self-extracting '.exe' file with the 'unzip' utility and searching for the 'sihp1000.img' file. Copy this file into the '/etc/printer' directory. There it will be found by the automatic uploader script and uploaded whenever the printer is connected and turned on.
");
@@ -3926,7 +3926,7 @@ sub hplip_help {
if ($hplipentry->{scan}) {
$text .= N("The scanner in your printer can be used with the usual SANE software, for example Kooka or XSane (Both in the Multimedia/Graphics menu). ");
- $text .= N("Run Scannerdrake (Hardware/Scanner in Mandrivalinux Control Center) to share your scanner on the network.\n\n");
+ $text .= N("Run Scannerdrake (Hardware/Scanner in Mandriva Linux Control Center) to share your scanner on the network.\n\n");
}
if (($hplipentry->{card} == 2) && ($deviceuri =~ m!/usb/!i)) {
diff --git a/perl-install/standalone/drakbug b/perl-install/standalone/drakbug
index 69dd95f24..b7b9fcbd9 100755
--- a/perl-install/standalone/drakbug
+++ b/perl-install/standalone/drakbug
@@ -1,8 +1,8 @@
#!/usr/bin/perl
# Drak Bug Report
-# Copyright (C) 2002-2004 Mandriva (daouda at mandrakesoft dot com)
-# Stew Benedict (sbenedict at mandrakesoft dot com)
+# Copyright (C) 2002-2004 Mandriva (daouda at mandriva dot com)
+# Stew Benedict (sbenedict at mandriva dot com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
@@ -38,12 +38,12 @@ foreach (@ARGV) {
/^--incident$/ && shift @ARGV and do { $incident = 1; $prog = shift @ARGV };
}
-my $window = ugtk2->new(N("Mandrivalinux Bug Report Tool"), center => 1);
+my $window = ugtk2->new(N("Mandriva Linux Bug Report Tool"), center => 1);
$window->{rwindow}->set_border_width(5);
$window->{window}->signal_connect("delete_event", sub { ugtk2->exit(0) });
my $mdk_app = {
- N("Mandrivalinux Control Center") => 'drakconf',
+ N("Mandriva Linux Control Center") => 'drakconf',
N("First Time Wizard") => 'drakfw',
N("Synchronization tool") => 'draksync',
N("Standalone Tools") => ['adduserdrake', 'diskdrake', 'drakautoinst', 'drakbackup', 'drakboot', 'DrakBug', 'DrakClock', 'DrakConnect', 'drakfloppy', 'drakfirewall', 'drakfont', 'drakgw', 'DrakSec', 'draksplash', 'drakvpn', 'drakxservices', 'drakxtools', 'drakxtv', 'keyboardrake', 'logdrake', 'mousedrake', 'net_monitor', 'printerdrake', 'scannerdrake', 'XFdrake'],
@@ -74,7 +74,7 @@ if ($mandrake_release =~ /(official|community)/i) {
} else {
$distrocode = "cooker";
}
-$bugzilla = 'http://qa.mandrakesoft.com/enter_bug.cgi';
+$bugzilla = 'http://qa.mandriva.com/enter_bug.cgi';
$wizard_name = "Bugzilla";
$table = create_packtable({ col_spacings => 5, row_spacings => 10 },
diff --git a/perl-install/standalone/drakconnect b/perl-install/standalone/drakconnect
index 2a2337733..16a237ea8 100755
--- a/perl-install/standalone/drakconnect
+++ b/perl-install/standalone/drakconnect
@@ -5,7 +5,7 @@
# Copyright (C) 1999-2004 Mandriva
# Damien "Dam's" Krotkine
# Damien "poulpy" Chaumette
-# Thierry Vignaud <tvignaud@mandrakesoft.com>
+# Thierry Vignaud <tvignaud@mandriva.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
@@ -951,7 +951,7 @@ Configure them first by clicking on 'Configure'")));
update();
});
} else {
- $widget_temp = N("This interface has not been configured yet.\nRun the \"Add an interface\" assistant from the Mandrivalinux Control Center");
+ $widget_temp = N("This interface has not been configured yet.\nRun the \"Add an interface\" assistant from the Mandriva Linux Control Center");
}
$vbox_local->pack_start(gtkpack__(Gtk2::HBox->new(0,0),
$widget_temp
@@ -1007,7 +1007,7 @@ sub configure_net {
N("Warning"),
#-PO: here "Add Connection" should be translated the same was as in control-center
N("You do not have any configured Internet connection.
-Run the \"%s\" assistant from the Mandrivalinux Control Center", N("Set up a new network interface (LAN, ISDN, ADSL, ...)")));
+Run the \"%s\" assistant from the Mandriva Linux Control Center", N("Set up a new network interface (LAN, ISDN, ADSL, ...)")));
$in->exit;
}
my $cnx = {};
diff --git a/perl-install/standalone/drakedm b/perl-install/standalone/drakedm
index 5ba4894c7..e3bc373ac 100644
--- a/perl-install/standalone/drakedm
+++ b/perl-install/standalone/drakedm
@@ -1,6 +1,6 @@
#!/usr/bin/perl
# DrakxDM -- Display Manager chooser
-# Copyright (C) 2003-2004 Mandriva (tvignaud@mandrakesoft.com)
+# Copyright (C) 2003-2004 Mandriva (tvignaud@mandriva.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ my $cfg_file = '/etc/sysconfig/desktop';
my %dm = ('GNOME' => [ N("GDM (GNOME Display Manager)"), '/usr/bin/gdm', 'gdm' ],
'KDM' => [ N("KDM (KDE Display Manager)"), '/usr/bin/kdm', 'kdebase-kdm' ],
- 'KDE' => [ N("MdkKDM (Mandrivalinux Display Manager)"), '/usr/bin/mdkkdm', 'mdkkdm' ],
+ 'KDE' => [ N("MdkKDM (Mandriva Linux Display Manager)"), '/usr/bin/mdkkdm', 'mdkkdm' ],
'XDM' => [ N("XDM (X Display Manager)"), '/usr/bin/X11/xdm', 'xorg-x11' ],
);
diff --git a/perl-install/standalone/drakhelp b/perl-install/standalone/drakhelp
index 303c06d9a..4c13e79dd 100644
--- a/perl-install/standalone/drakhelp
+++ b/perl-install/standalone/drakhelp
@@ -33,6 +33,6 @@ my $in = interactive->vnew;
my ($instpath, $ancpath, $package) = ctxhelp::path2help($opt, $idlabel);
-e $instpath or system("/usr/sbin/drakhelp_inst $package");
--e $instpath or $in->ask_warn(N("Mandrivalinux Help Center"), N("%s cannot be displayed \n. No Help entry of this type\n", $instpath));
+-e $instpath or $in->ask_warn(N("Mandriva Linux Help Center"), N("%s cannot be displayed \n. No Help entry of this type\n", $instpath));
system("/usr/bin/www-browser $ancpath &") if -e $instpath;
diff --git a/perl-install/standalone/logdrake b/perl-install/standalone/logdrake
index 339509723..fd2a27cb6 100755
--- a/perl-install/standalone/logdrake
+++ b/perl-install/standalone/logdrake
@@ -2,7 +2,7 @@
# $Id$
# Copyright (C) 2001-2004 Mandriva
-# Yves Duret <yduret at mandrakesoft.com>
+# Yves Duret <yduret at mandriva.com>
# some code is Copyright: (C) 1999, Michael T. Babcock <mikebabcock@pobox.com>
#
# This program is free software; you can redistribute it and/or modify
@@ -47,7 +47,7 @@ $| = 1 if $isTail;
my $h = chomp_(`hostname -s`);
$ugtk2::wm_icon = "logdrake";
-my $explain_title = N("Mandrivalinux Tools Logs");
+my $explain_title = N("Mandriva Linux Tools Logs");
my $my_win = ugtk2->new($isExplain ? $explain_title : N("Logdrake"));
unless ($::isEmbedded) {
diff --git a/perl-install/standalone/net_applet b/perl-install/standalone/net_applet
index c7e5d581a..e3bab7c67 100644
--- a/perl-install/standalone/net_applet
+++ b/perl-install/standalone/net_applet
@@ -59,7 +59,7 @@ my %appletstate = (
menu => [ 'confNetwork', 'refresh', 'help' ],
tt => [
N_("You do not have any configured Internet connection.
-Run the \"%s\" assistant from the Mandrivalinux Control Center", N("Set up a new network interface (LAN, ISDN, ADSL, ...)"))
+Run the \"%s\" assistant from the Mandriva Linux Control Center", N("Set up a new network interface (LAN, ISDN, ADSL, ...)"))
]
}
);
diff --git a/perl-install/standalone/net_monitor b/perl-install/standalone/net_monitor
index 78e7eab4f..05828517d 100755
--- a/perl-install/standalone/net_monitor
+++ b/perl-install/standalone/net_monitor
@@ -4,7 +4,7 @@
# Copyright (C) 1999-2004 Mandriva
# Damien "Dam's" Krotkine
-# Thierry Vignaud <tvignaud@mandrakesoft.com>
+# Thierry Vignaud <tvignaud@mandriva.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
@@ -233,7 +233,7 @@ sub connection() {
N("Disconnection from Internet complete.")) :
($isconnected ?
N("Connection complete.") :
- N("Connection failed.\nVerify your configuration in the Mandrivalinux Control Center."))
+ N("Connection failed.\nVerify your configuration in the Mandriva Linux Control Center."))
);
# remove the connection time timer if connection is down or failed
$isconnected or Glib::Source->remove($ct_tag);
diff --git a/perl-install/standalone/scannerdrake b/perl-install/standalone/scannerdrake
index be0ec07b2..fdfc92303 100755
--- a/perl-install/standalone/scannerdrake
+++ b/perl-install/standalone/scannerdrake
@@ -1,8 +1,8 @@
#!/usr/bin/perl
# scannerdrake $Id$
-# Yves Duret <yduret at mandrakesoft.com>
-# Till Kamppeter <till at mandrakesoft.com>
+# Yves Duret <yduret at mandriva.com>
+# Till Kamppeter <till at mandriva.com>
# Copyright (C) 2001-2004 Mandriva
#
# This program is free software; you can redistribute it and/or modify
@@ -30,8 +30,8 @@ use handle_configs;
use services;
my $companyname = "Mandriva";
-my $distroname = "Mandrivalinux";
-my $shortdistroname = "Mandrivalinux";
+my $distroname = "Mandriva Linux";
+my $shortdistroname = "Mandriva Linux";
my $domainname = "mandriva.com";
foreach (@ARGV) {
diff --git a/perl-install/help.pm b/perl-install/help.pm
index 61b886be1..5642e2350 100644
--- a/perl-install/help.pm
+++ b/perl-install/help.pm
@@ -5,11 +5,11 @@ use common;
# IMPORTANT: Do not edit this File - It is automatically generated
# from the manuals !!!
# Write a mail to <documentation@mandrakesoft.com> if
# you want it changed.
sub acceptLicense() {
N("Before continuing, you should carefully read the terms of the license. It
-covers the entire Mandrivalinux distribution. If you agree with all the
+covers the entire Mandriva Linux distribution. If you agree with all the
terms it contains, check the \"%s\" box. If not, clicking on the \"%s\"
button will reboot your computer.", N("Accept"), N("Quit"));
}
@@ -82,7 +82,7 @@ With SCSI hard drives, an \"a\" means \"lowest SCSI ID\", a \"b\" means
\"second lowest SCSI ID\", etc.");
}
sub chooseCd() {
- N("The Mandrivalinux installation is distributed on several CD-ROMs. If a
+ N("The Mandriva Linux installation is distributed on several CD-ROMs. If a
selected package is located on another CD-ROM, DrakX will eject the current
CD and ask you to insert the required one. If you do not have the requested
CD at hand, just click on \"%s\", the corresponding packages will not be
@@ -90,11 +90,11 @@ installed.", N("Cancel"));
}
sub choosePackages() {
N("It's now time to specify which programs you wish to install on your system.
-There are thousands of packages available for Mandrivalinux, and to make it
+There are thousands of packages available for Mandriva Linux, and to make it
simpler to manage, they have been placed into groups of similar
applications.
-Mandrivalinux sorts package groups in four categories. You can mix and
+Mandriva Linux sorts package groups in four categories. You can mix and
match applications from the various categories, so a ``Workstation''
installation can still have applications from the ``Server'' category
installed.
@@ -157,10 +157,10 @@ right to let you know the purpose of that package.
!! If a server package has been selected, either because you specifically
chose the individual package or because it was part of a group of packages,
you'll be asked to confirm that you really want those servers to be
-installed. By default Mandrivalinux will automatically start any installed
+installed. By default Mandriva Linux will automatically start any installed
services at boot time. Even if they are safe and have no known issues at
the time the distribution was shipped, it is entirely possible that
-security holes were discovered after this version of Mandrivalinux was
+security holes were discovered after this version of Mandriva Linux was
finalized. If you do not know what a particular service is supposed to do or
why it's being installed, then click \"%s\". Clicking \"%s\" will install
the listed services and they will be started automatically at boot time. !!
@@ -230,7 +230,7 @@ best suits your needs.");
sub configureX_chooser() {
N("X (for X Window System) is the heart of the GNU/Linux graphical interface
on which all the graphical environments (KDE, GNOME, AfterStep,
-WindowMaker, etc.) bundled with Mandrivalinux rely upon.
+WindowMaker, etc.) bundled with Mandriva Linux rely upon.
You'll see a list of different parameters to change to get an optimal
graphical display.
@@ -313,12 +313,12 @@ want to check \"%s\" if your machine is to act as a server, or if you were
not successful in getting the display configured.", N("No"));
}
sub doPartitionDisks() {
- N("You now need to decide where you want to install the Mandrivalinux
+ N("You now need to decide where you want to install the Mandriva Linux
operating system on your hard drive. If your hard drive is empty or if an
existing operating system is using all the available space you will have to
partition the drive. Basically, partitioning a hard drive means to
logically divide it to create the space needed to install your new
-Mandrivalinux system.
+Mandriva Linux system.
Because the process of partitioning a hard drive is usually irreversible
and can lead to data losses, partitioning can be intimidating and stressful
@@ -345,7 +345,7 @@ data (see ``Erase entire disk'' solution) or resize your Microsoft Windows
FAT or NTFS partition. Resizing can be performed without the loss of any
data, provided you've previously defragmented the Windows partition.
Backing up your data is strongly recommended. Using this option is
-recommended if you want to use both Mandrivalinux and Microsoft Windows on
+recommended if you want to use both Mandriva Linux and Microsoft Windows on
the same computer.
Before choosing this option, please understand that after this
@@ -354,7 +354,7 @@ than when you started. You'll have less free space under Microsoft Windows
to store your data or to install new software.
* \"%s\". If you want to delete all data and all partitions present on
-your hard drive and replace them with your new Mandrivalinux system, choose
+your hard drive and replace them with your new Mandriva Linux system, choose
this option. Be careful, because you will not be able to undo this operation
after you confirm.
@@ -425,13 +425,13 @@ will not be able to recover it.
Click on \"%s\" when you're ready to format the partitions.
Click on \"%s\" if you want to choose another partition for your new
-Mandrivalinux operating system installation.
+Mandriva Linux operating system installation.
Click on \"%s\" if you wish to select partitions which will be checked for
bad blocks on the disk.", N("Next"), N("Previous"), N("Advanced"));
}
sub installUpdates() {
- N("By the time you install Mandrivalinux, it's likely that some packages will
+ N("By the time you install Mandriva Linux, it's likely that some packages will
have been updated since the initial release. Bugs may have been fixed,
security issues resolved. To allow you to benefit from these updates,
you're now able to download them from the Internet. Check \"%s\" if you
@@ -451,7 +451,7 @@ exposed to the Internet. The trade-off that a higher security level is
generally obtained at the expense of ease of use.
If you do not know what to choose, keep the default option. You'll be able
-to change it later with the draksec tool, which is part of Mandrivalinux
+to change it later with the draksec tool, which is part of Mandriva Linux
Control Center.
Fill the \"%s\" field with the e-mail address of the person responsible for
@@ -459,7 +459,7 @@ security. Security messages will be sent to that address.", N("Security Administ
}
sub partition_with_diskdrake() {
N("At this point, you need to choose which partition(s) will be used for the
-installation of your Mandrivalinux system. If partitions have already been
+installation of your Mandriva Linux system. If partitions have already been
defined, either from a previous installation of GNU/Linux or by another
partitioning tool, you can use existing partitions. Otherwise, hard drive
partitions must be defined.
@@ -532,7 +532,7 @@ emergency boot situations.", N("Clear all"), N("Auto allocate"), N("More"), N("S
sub resizeFATChoose() {
N("More than one Microsoft partition has been detected on your hard drive.
Please choose the one which you want to resize in order to install your new
-Mandrivalinux operating system.
+Mandriva Linux operating system.
Each partition is listed as follows: \"Linux name\", \"Windows name\"
\"Capacity\".
@@ -570,7 +570,7 @@ sub selectInstallClass() {
found on your machine.
DrakX now needs to know if you want to perform a new installation or an
-upgrade of an existing Mandrivalinux system:
+upgrade of an existing Mandriva Linux system:
* \"%s\". For the most part, this completely wipes out the old system.
However, depending on your partitioning scheme, you can prevent some of
@@ -579,13 +579,13 @@ If you wish to change how your hard drives are partitioned, or to change
the file system, you should use this option.
* \"%s\". This installation class allows you to update the packages
-currently installed on your Mandrivalinux system. Your current partitioning
+currently installed on your Mandriva Linux system. Your current partitioning
scheme and user data will not be altered. Most of the other configuration
steps remain available and are similar to a standard installation.
-Using the ``Upgrade'' option should work fine on Mandrivalinux systems
+Using the ``Upgrade'' option should work fine on Mandriva Linux systems
running version \"8.1\" or later. Performing an upgrade on versions prior
-to Mandrivalinux version \"8.1\" is not recommended.", N("Install"), N("Upgrade"));
+to Mandriva Linux version \"8.1\" is not recommended.", N("Install"), N("Upgrade"));
}
sub selectKeyboard() {
N("Depending on the language you chose (), DrakX will automatically select a
@@ -620,7 +620,7 @@ the tree view and \"%s\" in the Advanced section.
About UTF-8 (unicode) support: Unicode is a new character encoding meant to
cover all existing languages. However full support for it in GNU/Linux is
-still under development. For that reason, Mandrivalinux's use of UTF-8 will
+still under development. For that reason, Mandriva Linux's use of UTF-8 will
depend on the user's choices:
* If you choose a language with a strong legacy encoding (latin1
@@ -740,7 +740,7 @@ know what you're doing.", N("First sector of drive (MBR)"), N("Skip"));
}
sub setupDefaultSpooler() {
N("Now, it's time to select a printing system for your computer. Other
-operating systems may offer you one, but Mandrivalinux offers two. Each of
+operating systems may offer you one, but Mandriva Linux offers two. Each of
the printing systems is best suited to particular types of configuration.
* \"%s\" -- which is an acronym for ``print, do not queue'', is the choice
@@ -761,7 +761,7 @@ emulate a \"lpd\" server, make sure you turn on the \"cups-lpd\" daemon.
options and for managing the printer.
If you make a choice now, and later find that you do not like your printing
-system you may change it by running PrinterDrake from the Mandrivalinux
+system you may change it by running PrinterDrake from the Mandriva Linux
Control Center and clicking on the \"%s\" button.", N("pdq"), N("pdq"), N("CUPS"), N("CUPS"), N("Expert"));
}
sub setupSCSI() {
@@ -831,7 +831,7 @@ the card if you feel the configuration is wrong.
* \"%s\": if you wish to configure your Internet or local network access,
you can do so now. Refer to the printed documentation or use the
-Mandrivalinux Control Center after the installation has finished to benefit
+Mandriva Linux Control Center after the installation has finished to benefit
from full in-line help.
* \"%s\": allows to configure HTTP and FTP proxy addresses if the machine
@@ -848,7 +848,7 @@ firewall settings.
* \"%s\": if you wish to change your bootloader configuration, click this
button. This should be reserved to advanced users. Refer to the printed
documentation or the in-line help about bootloader configuration in the
-Mandrivalinux Control Center.
+Mandriva Linux Control Center.
* \"%s\": through this entry you can fine tune which services will be run
on your machine. If you plan to use this machine as a server it's a good
@@ -856,7 +856,7 @@ idea to review this setup.", N("Configure"), N("Keyboard"), N("Country / Region"
}
sub takeOverHdChoose() {
N("Choose the hard drive you want to erase in order to install your new
-Mandrivalinux partition. Be careful, all data on this drive will be lost
+Mandriva Linux partition. Be careful, all data on this drive will be lost
and will not be recoverable!");
}
sub takeOverHdConfirm() {
@@ -5,11 +5,11 @@ use common;
# IMPORTANT: Do not edit this File - It is automatically generated
# from the manuals !!!
-# Write a mail to <documentation@mandrakesoft.com> if
+# Write a mail to <documentation@mandriva.com> if
# you want it changed.
sub acceptLicense() {